pitchtools.ChromaticObject
==========================

.. abjad-lineage:: abjad.tools.pitchtools.ChromaticObject.ChromaticObject.ChromaticObject

.. autoclass:: abjad.tools.pitchtools.ChromaticObject.ChromaticObject.ChromaticObject
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.ChromaticObject.ChromaticObject.ChromaticObject.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.ChromaticObject.ChromaticObject.ChromaticObject.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ChromaticObject.ChromaticObject.ChromaticObject.__ge__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ChromaticObject.ChromaticObject.ChromaticObject.__gt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ChromaticObject.ChromaticObject.ChromaticObject.__le__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ChromaticObject.ChromaticObject.ChromaticObject.__lt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ChromaticObject.ChromaticObject.ChromaticObject.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ChromaticObject.ChromaticObject.ChromaticObject.__repr__
   :noindex:
